@@ -4,7 +4,7 @@
  * For LGPL see License.txt in the project root for license information.
  * For commercial licenses see https://www.tiny.cloud/
  *
- * Version: 5.8.2 (2021-06-23)
+ * Version: 5.10.9 (2023-11-15)
  */
 (function () {
     'use strict';
@@ -23,9 +23,9 @@
       };
     };
 
-    var global = tinymce.util.Tools.resolve('tinymce.PluginManager');
+    var global$3 = tinymce.util.Tools.resolve('tinymce.PluginManager');
 
-    var get = function (fullscreenState) {
+    var get$5 = function (fullscreenState) {
       return {
         isFullscreen: function () {
           return fullscreenState.get() !== null;
@@ -45,7 +45,7 @@
         return t;
       }
     };
-    var isType = function (type) {
+    var isType$1 = function (type) {
       return function (value) {
         return typeOf(value) === type;
       };
@@ -55,8 +55,8 @@
         return typeof value === type;
       };
     };
-    var isString = isType('string');
-    var isArray = isType('array');
+    var isString = isType$1('string');
+    var isArray = isType$1('array');
     var isBoolean = isSimpleType('boolean');
     var isNullable = function (a) {
       return a === null || a === undefined;
@@ -88,6 +88,9 @@
         return value;
       };
     };
+    var identity = function (x) {
+      return x;
+    };
     function curry(fn) {
       var initialArgs = [];
       for (var _i = 1; _i < arguments.length; _i++) {
@@ -109,20 +112,14 @@
       return NONE;
     };
     var NONE = function () {
-      var eq = function (o) {
-        return o.isNone();
-      };
       var call = function (thunk) {
         return thunk();
       };
-      var id = function (n) {
-        return n;
-      };
+      var id = identity;
       var me = {
         fold: function (n, _s) {
           return n();
         },
-        is: never,
         isSome: never,
         isNone: always,
         getOr: id,
@@ -139,9 +136,9 @@
         bind: none,
         exists: never,
         forall: always,
-        filter: none,
-        equals: eq,
-        equals_: eq,
+        filter: function () {
+          return none();
+        },
         toArray: function () {
           return [];
         },
@@ -161,9 +158,6 @@
         fold: function (n, s) {
           return s(a);
         },
-        is: function (v) {
-          return a === v;
-        },
         isSome: always,
         isNone: never,
         getOr: constant_a,
@@ -190,14 +184,6 @@
         },
         toString: function () {
           return 'some(' + a + ')';
-        },
-        equals: function (o) {
-          return o.is(a);
-        },
-        equals_: function (o, elementEq) {
-          return o.fold(never, function (b) {
-            return elementEq(a, b);
-          });
         }
       };
       return me;
@@ -211,7 +197,20 @@
       from: from
     };
 
-    var revocable = function (doRevoke) {
+    var __assign = function () {
+      __assign = Object.assign || function __assign(t) {
+        for (var s, i = 1, n = arguments.length; i < n; i++) {
+          s = arguments[i];
+          for (var p in s)
+            if (Object.prototype.hasOwnProperty.call(s, p))
+              t[p] = s[p];
+        }
+        return t;
+      };
+      return __assign.apply(this, arguments);
+    };
+
+    var singleton = function (doRevoke) {
       var subject = Cell(Optional.none());
       var revoke = function () {
         return subject.get().each(doRevoke);
@@ -223,6 +222,9 @@
       var isSet = function () {
         return subject.get().isSome();
       };
+      var get = function () {
+        return subject.get();
+      };
       var set = function (s) {
         revoke();
         subject.set(Optional.some(s));
@@ -230,34 +232,21 @@
       return {
         clear: clear,
         isSet: isSet,
+        get: get,
         set: set
       };
     };
     var unbindable = function () {
-      return revocable(function (s) {
+      return singleton(function (s) {
         return s.unbind();
       });
     };
     var value = function () {
-      var subject = Cell(Optional.none());
-      var clear = function () {
-        return subject.set(Optional.none());
-      };
-      var set = function (s) {
-        return subject.set(Optional.some(s));
-      };
-      var isSet = function () {
-        return subject.get().isSome();
-      };
+      var subject = singleton(noop);
       var on = function (f) {
         return subject.get().each(f);
       };
-      return {
-        clear: clear,
-        set: set,
-        isSet: isSet,
-        on: on
-      };
+      return __assign(__assign({}, subject), { on: on });
     };
 
     var nativePush = Array.prototype.push;
@@ -270,13 +259,13 @@
       }
       return r;
     };
-    var each = function (xs, f) {
+    var each$1 = function (xs, f) {
       for (var i = 0, len = xs.length; i < len; i++) {
         var x = xs[i];
         f(x, i);
       }
     };
-    var filter = function (xs, pred) {
+    var filter$1 = function (xs, pred) {
       var r = [];
       for (var i = 0, len = xs.length; i < len; i++) {
         var x = xs[i];
@@ -286,6 +275,20 @@
       }
       return r;
     };
+    var findUntil = function (xs, pred, until) {
+      for (var i = 0, len = xs.length; i < len; i++) {
+        var x = xs[i];
+        if (pred(x, i)) {
+          return Optional.some(x);
+        } else if (until(x, i)) {
+          break;
+        }
+      }
+      return Optional.none();
+    };
+    var find$1 = function (xs, pred) {
+      return findUntil(xs, pred, never);
+    };
     var flatten = function (xs) {
       var r = [];
       for (var i = 0, len = xs.length; i < len; ++i) {
@@ -296,18 +299,27 @@
       }
       return r;
     };
-    var bind = function (xs, f) {
+    var bind$3 = function (xs, f) {
       return flatten(map(xs, f));
     };
-    var get$1 = function (xs, i) {
+    var get$4 = function (xs, i) {
       return i >= 0 && i < xs.length ? Optional.some(xs[i]) : Optional.none();
     };
     var head = function (xs) {
-      return get$1(xs, 0);
+      return get$4(xs, 0);
+    };
+    var findMap = function (arr, f) {
+      for (var i = 0; i < arr.length; i++) {
+        var r = f(arr[i], i);
+        if (r.isSome()) {
+          return r;
+        }
+      }
+      return Optional.none();
     };
 
     var keys = Object.keys;
-    var each$1 = function (obj, f) {
+    var each = function (obj, f) {
       var props = keys(obj);
       for (var k = 0, len = props.length; k < len; k++) {
         var i = props[k];
@@ -316,7 +328,11 @@
       }
     };
 
-    var isSupported = function (dom) {
+    var contains = function (str, substr) {
+      return str.indexOf(substr) !== -1;
+    };
+
+    var isSupported$1 = function (dom) {
       return dom.style !== undefined && isFunction(dom.style.getPropertyValue);
     };
 
@@ -357,7 +373,7 @@
       fromPoint: fromPoint
     };
 
-    var Global = typeof window !== 'undefined' ? window : Function('return this;')();
+    typeof window !== 'undefined' ? window : Function('return this;')();
 
     var DOCUMENT = 9;
     var DOCUMENT_FRAGMENT = 11;
@@ -367,15 +383,367 @@
     var type = function (element) {
       return element.dom.nodeType;
     };
-    var isType$1 = function (t) {
+    var isType = function (t) {
       return function (element) {
         return type(element) === t;
       };
     };
-    var isElement = isType$1(ELEMENT);
-    var isText = isType$1(TEXT);
-    var isDocument = isType$1(DOCUMENT);
-    var isDocumentFragment = isType$1(DOCUMENT_FRAGMENT);
+    var isElement = isType(ELEMENT);
+    var isText = isType(TEXT);
+    var isDocument = isType(DOCUMENT);
+    var isDocumentFragment = isType(DOCUMENT_FRAGMENT);
+
+    var cached = function (f) {
+      var called = false;
+      var r;
+      return function () {
+        var args = [];
+        for (var _i = 0; _i < arguments.length; _i++) {
+          args[_i] = arguments[_i];
+        }
+        if (!called) {
+          called = true;
+          r = f.apply(null, args);
+        }
+        return r;
+      };
+    };
+
+    var DeviceType = function (os, browser, userAgent, mediaMatch) {
+      var isiPad = os.isiOS() && /ipad/i.test(userAgent) === true;
+      var isiPhone = os.isiOS() && !isiPad;
+      var isMobile = os.isiOS() || os.isAndroid();
+      var isTouch = isMobile || mediaMatch('(pointer:coarse)');
+      var isTablet = isiPad || !isiPhone && isMobile && mediaMatch('(min-device-width:768px)');
+      var isPhone = isiPhone || isMobile && !isTablet;
+      var iOSwebview = browser.isSafari() && os.isiOS() && /safari/i.test(userAgent) === false;
+      var isDesktop = !isPhone && !isTablet && !iOSwebview;
+      return {
+        isiPad: constant(isiPad),
+        isiPhone: constant(isiPhone),
+        isTablet: constant(isTablet),
+        isPhone: constant(isPhone),
+        isTouch: constant(isTouch),
+        isAndroid: os.isAndroid,
+        isiOS: os.isiOS,
+        isWebView: constant(iOSwebview),
+        isDesktop: constant(isDesktop)
+      };
+    };
+
+    var firstMatch = function (regexes, s) {
+      for (var i = 0; i < regexes.length; i++) {
+        var x = regexes[i];
+        if (x.test(s)) {
+          return x;
+        }
+      }
+      return undefined;
+    };
+    var find = function (regexes, agent) {
+      var r = firstMatch(regexes, agent);
+      if (!r) {
+        return {
+          major: 0,
+          minor: 0
+        };
+      }
+      var group = function (i) {
+        return Number(agent.replace(r, '$' + i));
+      };
+      return nu$2(group(1), group(2));
+    };
+    var detect$3 = function (versionRegexes, agent) {
+      var cleanedAgent = String(agent).toLowerCase();
+      if (versionRegexes.length === 0) {
+        return unknown$2();
+      }
+      return find(versionRegexes, cleanedAgent);
+    };
+    var unknown$2 = function () {
+      return nu$2(0, 0);
+    };
+    var nu$2 = function (major, minor) {
+      return {
+        major: major,
+        minor: minor
+      };
+    };
+    var Version = {
+      nu: nu$2,
+      detect: detect$3,
+      unknown: unknown$2
+    };
+
+    var detectBrowser$1 = function (browsers, userAgentData) {
+      return findMap(userAgentData.brands, function (uaBrand) {
+        var lcBrand = uaBrand.brand.toLowerCase();
+        return find$1(browsers, function (browser) {
+          var _a;
+          return lcBrand === ((_a = browser.brand) === null || _a === void 0 ? void 0 : _a.toLowerCase());
+        }).map(function (info) {
+          return {
+            current: info.name,
+            version: Version.nu(parseInt(uaBrand.version, 10), 0)
+          };
+        });
+      });
+    };
+
+    var detect$2 = function (candidates, userAgent) {
+      var agent = String(userAgent).toLowerCase();
+      return find$1(candidates, function (candidate) {
+        return candidate.search(agent);
+      });
+    };
+    var detectBrowser = function (browsers, userAgent) {
+      return detect$2(browsers, userAgent).map(function (browser) {
+        var version = Version.detect(browser.versionRegexes, userAgent);
+        return {
+          current: browser.name,
+          version: version
+        };
+      });
+    };
+    var detectOs = function (oses, userAgent) {
+      return detect$2(oses, userAgent).map(function (os) {
+        var version = Version.detect(os.versionRegexes, userAgent);
+        return {
+          current: os.name,
+          version: version
+        };
+      });
+    };
+
+    var normalVersionRegex = /.*?version\/\ ?([0-9]+)\.([0-9]+).*/;
+    var checkContains = function (target) {
+      return function (uastring) {
+        return contains(uastring, target);
+      };
+    };
+    var browsers = [
+      {
+        name: 'Edge',
+        versionRegexes: [/.*?edge\/ ?([0-9]+)\.([0-9]+)$/],
+        search: function (uastring) {
+          return contains(uastring, 'edge/') && contains(uastring, 'chrome') && contains(uastring, 'safari') && contains(uastring, 'applewebkit');
+        }
+      },
+      {
+        name: 'Chrome',
+        brand: 'Chromium',
+        versionRegexes: [
+          /.*?chrome\/([0-9]+)\.([0-9]+).*/,
+          normalVersionRegex
+        ],
+        search: function (uastring) {
+          return contains(uastring, 'chrome') && !contains(uastring, 'chromeframe');
+        }
+      },
+      {
+        name: 'IE',
+        versionRegexes: [
+          /.*?msie\ ?([0-9]+)\.([0-9]+).*/,
+          /.*?rv:([0-9]+)\.([0-9]+).*/
+        ],
+        search: function (uastring) {
+          return contains(uastring, 'msie') || contains(uastring, 'trident');
+        }
+      },
+      {
+        name: 'Opera',
+        versionRegexes: [
+          normalVersionRegex,
+          /.*?opera\/([0-9]+)\.([0-9]+).*/
+        ],
+        search: checkContains('opera')
+      },
+      {
+        name: 'Firefox',
+        versionRegexes: [/.*?firefox\/\ ?([0-9]+)\.([0-9]+).*/],
+        search: checkContains('firefox')
+      },
+      {
+        name: 'Safari',
+        versionRegexes: [
+          normalVersionRegex,
+          /.*?cpu os ([0-9]+)_([0-9]+).*/
+        ],
+        search: function (uastring) {
+          return (contains(uastring, 'safari') || contains(uastring, 'mobile/')) && contains(uastring, 'applewebkit');
+        }
+      }
+    ];
+    var oses = [
+      {
+        name: 'Windows',
+        search: checkContains('win'),
+        versionRegexes: [/.*?windows\ nt\ ?([0-9]+)\.([0-9]+).*/]
+      },
+      {
+        name: 'iOS',
+        search: function (uastring) {
+          return contains(uastring, 'iphone') || contains(uastring, 'ipad');
+        },
+        versionRegexes: [
+          /.*?version\/\ ?([0-9]+)\.([0-9]+).*/,
+          /.*cpu os ([0-9]+)_([0-9]+).*/,
+          /.*cpu iphone os ([0-9]+)_([0-9]+).*/
+        ]
+      },
+      {
+        name: 'Android',
+        search: checkContains('android'),
+        versionRegexes: [/.*?android\ ?([0-9]+)\.([0-9]+).*/]
+      },
+      {
+        name: 'OSX',
+        search: checkContains('mac os x'),
+        versionRegexes: [/.*?mac\ os\ x\ ?([0-9]+)_([0-9]+).*/]
+      },
+      {
+        name: 'Linux',
+        search: checkContains('linux'),
+        versionRegexes: []
+      },
+      {
+        name: 'Solaris',
+        search: checkContains('sunos'),
+        versionRegexes: []
+      },
+      {
+        name: 'FreeBSD',
+        search: checkContains('freebsd'),
+        versionRegexes: []
+      },
+      {
+        name: 'ChromeOS',
+        search: checkContains('cros'),
+        versionRegexes: [/.*?chrome\/([0-9]+)\.([0-9]+).*/]
+      }
+    ];
+    var PlatformInfo = {
+      browsers: constant(browsers),
+      oses: constant(oses)
+    };
+
+    var edge = 'Edge';
+    var chrome = 'Chrome';
+    var ie = 'IE';
+    var opera = 'Opera';
+    var firefox = 'Firefox';
+    var safari = 'Safari';
+    var unknown$1 = function () {
+      return nu$1({
+        current: undefined,
+        version: Version.unknown()
+      });
+    };
+    var nu$1 = function (info) {
+      var current = info.current;
+      var version = info.version;
+      var isBrowser = function (name) {
+        return function () {
+          return current === name;
+        };
+      };
+      return {
+        current: current,
+        version: version,
+        isEdge: isBrowser(edge),
+        isChrome: isBrowser(chrome),
+        isIE: isBrowser(ie),
+        isOpera: isBrowser(opera),
+        isFirefox: isBrowser(firefox),
+        isSafari: isBrowser(safari)
+      };
+    };
+    var Browser = {
+      unknown: unknown$1,
+      nu: nu$1,
+      edge: constant(edge),
+      chrome: constant(chrome),
+      ie: constant(ie),
+      opera: constant(opera),
+      firefox: constant(firefox),
+      safari: constant(safari)
+    };
+
+    var windows = 'Windows';
+    var ios = 'iOS';
+    var android = 'Android';
+    var linux = 'Linux';
+    var osx = 'OSX';
+    var solaris = 'Solaris';
+    var freebsd = 'FreeBSD';
+    var chromeos = 'ChromeOS';
+    var unknown = function () {
+      return nu({
+        current: undefined,
+        version: Version.unknown()
+      });
+    };
+    var nu = function (info) {
+      var current = info.current;
+      var version = info.version;
+      var isOS = function (name) {
+        return function () {
+          return current === name;
+        };
+      };
+      return {
+        current: current,
+        version: version,
+        isWindows: isOS(windows),
+        isiOS: isOS(ios),
+        isAndroid: isOS(android),
+        isOSX: isOS(osx),
+        isLinux: isOS(linux),
+        isSolaris: isOS(solaris),
+        isFreeBSD: isOS(freebsd),
+        isChromeOS: isOS(chromeos)
+      };
+    };
+    var OperatingSystem = {
+      unknown: unknown,
+      nu: nu,
+      windows: constant(windows),
+      ios: constant(ios),
+      android: constant(android),
+      linux: constant(linux),
+      osx: constant(osx),
+      solaris: constant(solaris),
+      freebsd: constant(freebsd),
+      chromeos: constant(chromeos)
+    };
+
+    var detect$1 = function (userAgent, userAgentDataOpt, mediaMatch) {
+      var browsers = PlatformInfo.browsers();
+      var oses = PlatformInfo.oses();
+      var browser = userAgentDataOpt.bind(function (userAgentData) {
+        return detectBrowser$1(browsers, userAgentData);
+      }).orThunk(function () {
+        return detectBrowser(browsers, userAgent);
+      }).fold(Browser.unknown, Browser.nu);
+      var os = detectOs(oses, userAgent).fold(OperatingSystem.unknown, OperatingSystem.nu);
+      var deviceType = DeviceType(os, browser, userAgent, mediaMatch);
+      return {
+        browser: browser,
+        os: os,
+        deviceType: deviceType
+      };
+    };
+    var PlatformDetection = { detect: detect$1 };
+
+    var mediaMatch = function (query) {
+      return window.matchMedia(query).matches;
+    };
+    var platform = cached(function () {
+      return PlatformDetection.detect(navigator.userAgent, Optional.from(navigator.userAgentData), mediaMatch);
+    });
+    var detect = function () {
+      return platform();
+    };
 
     var is = function (element, selector) {
       var dom = element.dom;
@@ -399,7 +767,7 @@
     var bypassSelector = function (dom) {
       return dom.nodeType !== ELEMENT && dom.nodeType !== DOCUMENT && dom.nodeType !== DOCUMENT_FRAGMENT || dom.childElementCount === 0;
     };
-    var all = function (selector, scope) {
+    var all$1 = function (selector, scope) {
       var base = scope === undefined ? document : scope.dom;
       return bypassSelector(base) ? [] : map(base.querySelectorAll(selector), SugarElement.fromDom);
     };
@@ -433,9 +801,9 @@
       }
       return ret;
     };
-    var siblings = function (element) {
+    var siblings$2 = function (element) {
       var filterSelf = function (elements) {
-        return filter(elements, function (x) {
+        return filter$1(elements, function (x) {
           return !eq(element, x);
         });
       };
@@ -449,7 +817,7 @@
       return isDocumentFragment(dos) && isNonNullable(dos.dom.host);
     };
     var supported = isFunction(Element.prototype.attachShadow) && isFunction(Node.prototype.getRootNode);
-    var isSupported$1 = constant(supported);
+    var isSupported = constant(supported);
     var getRootNode = supported ? function (e) {
       return SugarElement.fromDom(e.dom.getRootNode());
     } : documentOrOwner;
@@ -461,7 +829,7 @@
       return SugarElement.fromDom(e.dom.host);
     };
     var getOriginalEventTarget = function (event) {
-      if (isSupported$1() && isNonNullable(event.target)) {
+      if (isSupported() && isNonNullable(event.target)) {
         var el = SugarElement.fromDom(event.target);
         if (isElement(el) && isOpenShadowHost(el)) {
           if (event.composed && event.composedPath) {
@@ -507,7 +875,7 @@
     var set = function (element, key, value) {
       rawSet(element.dom, key, value);
     };
-    var get$2 = function (element, key) {
+    var get$3 = function (element, key) {
       var v = element.dom.getAttribute(key);
       return v === null ? undefined : v;
     };
@@ -520,24 +888,24 @@
         console.error('Invalid call to CSS.set. Property ', property, ':: Value ', value, ':: Element ', dom);
         throw new Error('CSS value must be a string: ' + value);
       }
-      if (isSupported(dom)) {
+      if (isSupported$1(dom)) {
         dom.style.setProperty(property, value);
       }
     };
     var setAll = function (element, css) {
       var dom = element.dom;
-      each$1(css, function (v, k) {
+      each(css, function (v, k) {
         internalSet(dom, k, v);
       });
     };
-    var get$3 = function (element, property) {
+    var get$2 = function (element, property) {
       var dom = element.dom;
       var styles = window.getComputedStyle(dom);
       var r = styles.getPropertyValue(property);
       return r === '' && !inBody(element) ? getUnsafeProperty(dom, property) : r;
     };
     var getUnsafeProperty = function (dom, property) {
-      return isSupported(dom) ? dom.style.getPropertyValue(property) : '';
+      return isSupported$1(dom) ? dom.style.getPropertyValue(property) : '';
     };
 
     var mkEvent = function (target, x, y, stop, prevent, kill, raw) {
@@ -574,16 +942,16 @@
       element.dom.addEventListener(event, wrapped, useCapture);
       return { unbind: curry(unbind, element, event, wrapped, useCapture) };
     };
-    var bind$1 = function (element, event, filter, handler) {
+    var bind$2 = function (element, event, filter, handler) {
       return binder(element, event, filter, handler, false);
     };
     var unbind = function (element, event, handler, useCapture) {
       element.dom.removeEventListener(event, handler, useCapture);
     };
 
-    var filter$1 = always;
-    var bind$2 = function (element, event, handler) {
-      return bind$1(element, event, filter$1, handler);
+    var filter = always;
+    var bind$1 = function (element, event, handler) {
+      return bind$2(element, event, filter, handler);
     };
 
     var r = function (left, top) {
@@ -598,16 +966,20 @@
     };
     var SugarPosition = r;
 
-    var get$4 = function (_DOC) {
+    var get$1 = function (_DOC) {
       var doc = _DOC !== undefined ? _DOC.dom : document;
       var x = doc.body.scrollLeft || doc.documentElement.scrollLeft;
       var y = doc.body.scrollTop || doc.documentElement.scrollTop;
       return SugarPosition(x, y);
     };
 
-    var get$5 = function (_win) {
+    var get = function (_win) {
       var win = _win === undefined ? window : _win;
-      return Optional.from(win['visualViewport']);
+      if (detect().browser.isFirefox()) {
+        return Optional.none();
+      } else {
+        return Optional.from(win['visualViewport']);
+      }
     };
     var bounds = function (x, y, width, height) {
       return {
@@ -622,8 +994,8 @@
     var getBounds = function (_win) {
       var win = _win === undefined ? window : _win;
       var doc = win.document;
-      var scroll = get$4(SugarElement.fromDom(doc));
-      return get$5(win).fold(function () {
+      var scroll = get$1(SugarElement.fromDom(doc));
+      return get(win).fold(function () {
         var html = win.document.documentElement;
         var width = html.clientWidth;
         var height = html.clientHeight;
@@ -632,8 +1004,8 @@
         return bounds(Math.max(visualViewport.pageLeft, scroll.left), Math.max(visualViewport.pageTop, scroll.top), visualViewport.width, visualViewport.height);
       });
     };
-    var bind$3 = function (name, callback, _win) {
-      return get$5(_win).map(function (visualViewport) {
+    var bind = function (name, callback, _win) {
+      return get(_win).map(function (visualViewport) {
         var handler = function (e) {
           return callback(fromRawEvent(e));
         };
@@ -648,14 +1020,15 @@
       });
     };
 
-    var global$1 = tinymce.util.Tools.resolve('tinymce.dom.DOMUtils');
+    var global$2 = tinymce.util.Tools.resolve('tinymce.dom.DOMUtils');
 
-    var global$2 = tinymce.util.Tools.resolve('tinymce.Env');
+    var global$1 = tinymce.util.Tools.resolve('tinymce.Env');
 
-    var global$3 = tinymce.util.Tools.resolve('tinymce.util.Delay');
+    var global = tinymce.util.Tools.resolve('tinymce.util.Delay');
 
     var fireFullscreenStateChanged = function (editor, state) {
       editor.fire('FullscreenStateChanged', { state: state });
+      editor.fire('ResizeEditor');
     };
 
     var getFullscreenNative = function (editor) {
@@ -714,22 +1087,22 @@
       return elem.dom === getFullscreenElement(owner(elem).dom);
     };
 
-    var ancestors = function (scope, predicate, isRoot) {
-      return filter(parents(scope, isRoot), predicate);
+    var ancestors$1 = function (scope, predicate, isRoot) {
+      return filter$1(parents(scope, isRoot), predicate);
     };
     var siblings$1 = function (scope, predicate) {
-      return filter(siblings(scope), predicate);
+      return filter$1(siblings$2(scope), predicate);
     };
 
-    var all$1 = function (selector) {
-      return all(selector);
+    var all = function (selector) {
+      return all$1(selector);
     };
-    var ancestors$1 = function (scope, selector, isRoot) {
-      return ancestors(scope, function (e) {
+    var ancestors = function (scope, selector, isRoot) {
+      return ancestors$1(scope, function (e) {
         return is(e, selector);
       }, isRoot);
     };
-    var siblings$2 = function (scope, selector) {
+    var siblings = function (scope, selector) {
       return siblings$1(scope, function (e) {
         return is(e, selector);
       });
@@ -740,18 +1113,18 @@
     var ancestorPosition = 'position:absolute!important;';
     var ancestorStyles = 'top:0!important;left:0!important;margin:0!important;padding:0!important;width:100%!important;height:100%!important;overflow:visible!important;';
     var bgFallback = 'background-color:rgb(255,255,255)!important;';
-    var isAndroid = global$2.os.isAndroid();
+    var isAndroid = global$1.os.isAndroid();
     var matchColor = function (editorBody) {
-      var color = get$3(editorBody, 'background-color');
+      var color = get$2(editorBody, 'background-color');
       return color !== undefined && color !== '' ? 'background-color:' + color + '!important' : bgFallback;
     };
     var clobberStyles = function (dom, container, editorBody) {
       var gatherSiblings = function (element) {
-        return siblings$2(element, '*:not(.tox-silver-sink)');
+        return siblings(element, '*:not(.tox-silver-sink)');
       };
       var clobber = function (clobberStyle) {
         return function (element) {
-          var styles = get$2(element, 'style');
+          var styles = get$3(element, 'style');
           var backup = styles === undefined ? 'no-styles' : styles.trim();
           if (backup === clobberStyle) {
             return;
@@ -761,18 +1134,18 @@
           }
         };
       };
-      var ancestors = ancestors$1(container, '*');
-      var siblings = bind(ancestors, gatherSiblings);
+      var ancestors$1 = ancestors(container, '*');
+      var siblings$1 = bind$3(ancestors$1, gatherSiblings);
       var bgColor = matchColor(editorBody);
-      each(siblings, clobber(siblingStyles));
-      each(ancestors, clobber(ancestorPosition + ancestorStyles + bgColor));
+      each$1(siblings$1, clobber(siblingStyles));
+      each$1(ancestors$1, clobber(ancestorPosition + ancestorStyles + bgColor));
       var containerStyles = isAndroid === true ? '' : ancestorPosition;
       clobber(containerStyles + ancestorStyles + bgColor)(container);
     };
     var restoreStyles = function (dom) {
-      var clobberedEls = all$1('[' + attr + ']');
-      each(clobberedEls, function (element) {
-        var restore = get$2(element, attr);
+      var clobberedEls = all('[' + attr + ']');
+      each$1(clobberedEls, function (element) {
+        var restore = get$3(element, attr);
         if (restore !== 'no-styles') {
           setAll(element, dom.parseStyle(restore));
         } else {
@@ -782,18 +1155,14 @@
       });
     };
 
-    var DOM = global$1.DOM;
+    var DOM = global$2.DOM;
     var getScrollPos = function () {
-      var vp = getBounds(window);
-      return {
-        x: vp.x,
-        y: vp.y
-      };
+      return getBounds(window);
     };
     var setScrollPos = function (pos) {
-      window.scrollTo(pos.x, pos.y);
+      return window.scrollTo(pos.x, pos.y);
     };
-    var viewportUpdate = get$5().fold(function () {
+    var viewportUpdate = get().fold(function () {
       return {
         bind: noop,
         unbind: noop
@@ -818,15 +1187,15 @@
           });
         });
       };
-      var update = global$3.throttle(function () {
+      var update = global.throttle(function () {
         refreshScroll();
         refreshVisualViewport();
       }, 50);
-      var bind = function (element) {
+      var bind$1 = function (element) {
         editorContainer.set(element);
         update();
-        resizeBinder.set(bind$3('resize', update));
-        scrollBinder.set(bind$3('scroll', update));
+        resizeBinder.set(bind('resize', update));
+        scrollBinder.set(bind('scroll', update));
       };
       var unbind = function () {
         editorContainer.on(function () {
@@ -836,7 +1205,7 @@
         editorContainer.clear();
       };
       return {
-        bind: bind,
+        bind: bind$1,
         unbind: unbind
       };
     });
@@ -848,7 +1217,7 @@
       var fullscreenRoot = getFullscreenRoot(editor);
       var fullscreenInfo = fullscreenState.get();
       var editorBody = SugarElement.fromDom(editor.getBody());
-      var isTouch = global$2.deviceType.isTouch();
+      var isTouch = global$1.deviceType.isTouch();
       var editorContainerStyle = editorContainer.style;
       var iframe = editor.iframeElement;
       var iframeStyle = iframe.style;
@@ -874,7 +1243,7 @@
         });
       };
       if (!fullscreenInfo) {
-        var fullscreenChangeHandler = bind$2(owner(fullscreenRoot), getFullscreenchangeEventName(), function (_evt) {
+        var fullscreenChangeHandler = bind$1(owner(fullscreenRoot), getFullscreenchangeEventName(), function (_evt) {
           if (getFullscreenNative(editor)) {
             if (!isFullscreenElement(fullscreenRoot) && fullscreenState.get() !== null) {
               toggleFullscreen(editor, fullscreenState);
@@ -915,15 +1284,15 @@
         editorContainerStyle.height = fullscreenInfo.containerHeight;
         editorContainerStyle.top = fullscreenInfo.containerTop;
         editorContainerStyle.left = fullscreenInfo.containerLeft;
+        cleanup();
         setScrollPos(fullscreenInfo.scrollPos);
         fullscreenState.set(null);
         fireFullscreenStateChanged(editor, false);
-        cleanup();
         editor.off('remove', cleanup);
       }
     };
 
-    var register = function (editor, fullscreenState) {
+    var register$1 = function (editor, fullscreenState) {
       editor.addCommand('mceFullScreen', function () {
         toggleFullscreen(editor, fullscreenState);
       });
@@ -941,36 +1310,35 @@
         };
       };
     };
-    var register$1 = function (editor, fullscreenState) {
+    var register = function (editor, fullscreenState) {
+      var onAction = function () {
+        return editor.execCommand('mceFullScreen');
+      };
       editor.ui.registry.addToggleMenuItem('fullscreen', {
         text: 'Fullscreen',
         icon: 'fullscreen',
         shortcut: 'Meta+Shift+F',
-        onAction: function () {
-          return editor.execCommand('mceFullScreen');
-        },
+        onAction: onAction,
         onSetup: makeSetupHandler(editor, fullscreenState)
       });
       editor.ui.registry.addToggleButton('fullscreen', {
         tooltip: 'Fullscreen',
         icon: 'fullscreen',
-        onAction: function () {
-          return editor.execCommand('mceFullScreen');
-        },
+        onAction: onAction,
         onSetup: makeSetupHandler(editor, fullscreenState)
       });
     };
 
     function Plugin () {
-      global.add('fullscreen', function (editor) {
+      global$3.add('fullscreen', function (editor) {
         var fullscreenState = Cell(null);
         if (editor.inline) {
-          return get(fullscreenState);
+          return get$5(fullscreenState);
         }
-        register(editor, fullscreenState);
         register$1(editor, fullscreenState);
+        register(editor, fullscreenState);
         editor.addShortcut('Meta+Shift+F', '', 'mceFullScreen');
-        return get(fullscreenState);
+        return get$5(fullscreenState);
       });
     }
 
