@@ -4,40 +4,39 @@
  * For LGPL see License.txt in the project root for license information.
  * For commercial licenses see https://www.tiny.cloud/
  *
- * Version: 5.8.2 (2021-06-23)
+ * Version: 5.10.9 (2023-11-15)
  */
 (function () {
     'use strict';
 
     var global = tinymce.util.Tools.resolve('tinymce.PluginManager');
 
-    var register = function (editor) {
+    var register$1 = function (editor) {
       editor.addCommand('InsertHorizontalRule', function () {
         editor.execCommand('mceInsertContent', false, '<hr />');
       });
     };
 
-    var register$1 = function (editor) {
+    var register = function (editor) {
+      var onAction = function () {
+        return editor.execCommand('InsertHorizontalRule');
+      };
       editor.ui.registry.addButton('hr', {
         icon: 'horizontal-rule',
         tooltip: 'Horizontal line',
-        onAction: function () {
-          return editor.execCommand('InsertHorizontalRule');
-        }
+        onAction: onAction
       });
       editor.ui.registry.addMenuItem('hr', {
         icon: 'horizontal-rule',
         text: 'Horizontal line',
-        onAction: function () {
-          return editor.execCommand('InsertHorizontalRule');
-        }
+        onAction: onAction
       });
     };
 
     function Plugin () {
       global.add('hr', function (editor) {
-        register(editor);
         register$1(editor);
+        register(editor);
       });
     }
 
