@@ -4,20 +4,40 @@
  * For LGPL see License.txt in the project root for license information.
  * For commercial licenses see https://www.tiny.cloud/
  *
- * Version: 5.8.2 (2021-06-23)
+ * Version: 5.10.9 (2023-11-15)
  */
 (function () {
     'use strict';
 
-    var global = tinymce.util.Tools.resolve('tinymce.PluginManager');
+    var global$4 = tinymce.util.Tools.resolve('tinymce.PluginManager');
 
-    var global$1 = tinymce.util.Tools.resolve('tinymce.dom.DOMUtils');
+    var typeOf = function (x) {
+      var t = typeof x;
+      if (x === null) {
+        return 'null';
+      } else if (t === 'object' && (Array.prototype.isPrototypeOf(x) || x.constructor && x.constructor.name === 'Array')) {
+        return 'array';
+      } else if (t === 'object' && (String.prototype.isPrototypeOf(x) || x.constructor && x.constructor.name === 'String')) {
+        return 'string';
+      } else {
+        return t;
+      }
+    };
+    var isType = function (type) {
+      return function (value) {
+        return typeOf(value) === type;
+      };
+    };
+    var isString = isType('string');
+    var isArray = isType('array');
+
+    var global$3 = tinymce.util.Tools.resolve('tinymce.dom.DOMUtils');
 
     var global$2 = tinymce.util.Tools.resolve('tinymce.EditorManager');
 
-    var global$3 = tinymce.util.Tools.resolve('tinymce.Env');
+    var global$1 = tinymce.util.Tools.resolve('tinymce.Env');
 
-    var global$4 = tinymce.util.Tools.resolve('tinymce.util.Tools');
+    var global = tinymce.util.Tools.resolve('tinymce.util.Tools');
 
     var shouldMergeClasses = function (editor) {
       return editor.getParam('importcss_merge_classes');
@@ -48,25 +68,6 @@
       return editor.getParam('skin_url');
     };
 
-    var typeOf = function (x) {
-      var t = typeof x;
-      if (x === null) {
-        return 'null';
-      } else if (t === 'object' && (Array.prototype.isPrototypeOf(x) || x.constructor && x.constructor.name === 'Array')) {
-        return 'array';
-      } else if (t === 'object' && (String.prototype.isPrototypeOf(x) || x.constructor && x.constructor.name === 'String')) {
-        return 'string';
-      } else {
-        return t;
-      }
-    };
-    var isType = function (type) {
-      return function (value) {
-        return typeOf(value) === type;
-      };
-    };
-    var isArray = isType('array');
-
     var nativePush = Array.prototype.push;
     var map = function (xs, f) {
       var len = xs.length;
@@ -123,9 +124,10 @@
       };
     };
 
+    var internalEditorStyle = /^\.(?:ephox|tiny-pageembed|mce)(?:[.-]+\w+)+$/;
     var removeCacheSuffix = function (url) {
-      var cacheSuffix = global$3.cacheSuffix;
-      if (typeof url === 'string') {
+      var cacheSuffix = global$1.cacheSuffix;
+      if (isString(url)) {
         url = url.replace('?' + cacheSuffix, '').replace('&' + cacheSuffix, '');
       }
       return url;
@@ -141,7 +143,7 @@
       return false;
     };
     var compileFilter = function (filter) {
-      if (typeof filter === 'string') {
+      if (isString(filter)) {
         return function (value) {
           return value.indexOf(filter) !== -1;
         };
@@ -159,31 +161,32 @@
       return rule.selectorText;
     };
     var getSelectors = function (editor, doc, fileFilter) {
-      var selectors = [], contentCSSUrls = {};
+      var selectors = [];
+      var contentCSSUrls = {};
       var append = function (styleSheet, imported) {
         var href = styleSheet.href, rules;
         href = removeCacheSuffix(href);
         if (!href || !fileFilter(href, imported) || isSkinContentCss(editor, href)) {
           return;
         }
-        global$4.each(styleSheet.imports, function (styleSheet) {
+        global.each(styleSheet.imports, function (styleSheet) {
           append(styleSheet, true);
         });
         try {
           rules = styleSheet.cssRules || styleSheet.rules;
         } catch (e) {
         }
-        global$4.each(rules, function (cssRule) {
+        global.each(rules, function (cssRule) {
           if (isCssImportRule(cssRule)) {
             append(cssRule.styleSheet, true);
           } else if (isCssPageRule(cssRule)) {
-            global$4.each(cssRule.selectorText.split(','), function (selector) {
-              selectors.push(global$4.trim(selector));
+            global.each(cssRule.selectorText.split(','), function (selector) {
+              selectors.push(global.trim(selector));
             });
           }
         });
       };
-      global$4.each(editor.contentCSS, function (url) {
+      global.each(editor.contentCSS, function (url) {
         contentCSSUrls[url] = true;
       });
       if (!fileFilter) {
@@ -192,7 +195,7 @@
         };
       }
       try {
-        global$4.each(doc.styleSheets, function (styleSheet) {
+        global.each(doc.styleSheets, function (styleSheet) {
           append(styleSheet);
         });
       } catch (e) {
@@ -207,7 +210,7 @@
       }
       var elementName = selector[1];
       var classes = selector[2].substr(1).split('.').join(' ');
-      var inlineSelectorElements = global$4.makeMap('a,img');
+      var inlineSelectorElements = global.makeMap('a,img');
       if (selector[1]) {
         format = { title: selectorText };
         if (editor.schema.getTextBlockElements()[elementName]) {
@@ -232,20 +235,16 @@
       return format;
     };
     var getGroupsBySelector = function (groups, selector) {
-      return global$4.grep(groups, function (group) {
+      return global.grep(groups, function (group) {
         return !group.filter || group.filter(selector);
       });
     };
     var compileUserDefinedGroups = function (groups) {
-      return global$4.map(groups, function (group) {
-        return global$4.extend({}, group, {
+      return global.map(groups, function (group) {
+        return global.extend({}, group, {
           original: group,
           selectors: {},
-          filter: compileFilter(group.filter),
-          item: {
-            text: group.title,
-            menu: []
-          }
+          filter: compileFilter(group.filter)
         });
       });
     };
@@ -276,7 +275,7 @@
       return selectorConverter.call(plugin, selector, group);
     };
     var setup = function (editor) {
-      editor.on('init', function (_e) {
+      editor.on('init', function () {
         var model = generate();
         var globallyUniqueSelectors = {};
         var selectorFilter = compileFilter(getSelectorFilter(editor));
@@ -286,22 +285,22 @@
             markUniqueSelector(editor, selector, group, globallyUniqueSelectors);
             var format = convertSelectorToFormat(editor, editor.plugins.importcss, selector, group);
             if (format) {
-              var formatName = format.name || global$1.DOM.uniqueId();
+              var formatName = format.name || global$3.DOM.uniqueId();
               editor.formatter.register(formatName, format);
-              return global$4.extend({}, {
+              return {
                 title: format.title,
                 format: formatName
-              });
+              };
             }
           }
           return null;
         };
-        global$4.each(getSelectors(editor, editor.getDoc(), compileFilter(getFileFilter(editor))), function (selector) {
-          if (selector.indexOf('.mce-') === -1) {
+        global.each(getSelectors(editor, editor.getDoc(), compileFilter(getFileFilter(editor))), function (selector) {
+          if (!internalEditorStyle.test(selector)) {
             if (!selectorFilter || selectorFilter(selector)) {
               var selectorGroups = getGroupsBySelector(groups, selector);
               if (selectorGroups.length > 0) {
-                global$4.each(selectorGroups, function (group) {
+                global.each(selectorGroups, function (group) {
                   var menuItem = processSelector(selector, group);
                   if (menuItem) {
                     model.addItemToGroup(group.title, menuItem);
@@ -332,7 +331,7 @@
     };
 
     function Plugin () {
-      global.add('importcss', function (editor) {
+      global$4.add('importcss', function (editor) {
         setup(editor);
         return get(editor);
       });
