@@ -4,18 +4,18 @@
  * For LGPL see License.txt in the project root for license information.
  * For commercial licenses see https://www.tiny.cloud/
  *
- * Version: 5.8.2 (2021-06-23)
+ * Version: 5.10.9 (2023-11-15)
  */
 (function () {
     'use strict';
 
-    var global = tinymce.util.Tools.resolve('tinymce.PluginManager');
+    var global$1 = tinymce.util.Tools.resolve('tinymce.PluginManager');
 
-    var global$1 = tinymce.util.Tools.resolve('tinymce.Env');
+    var global = tinymce.util.Tools.resolve('tinymce.Env');
 
-    var register = function (editor) {
+    var register$1 = function (editor) {
       editor.addCommand('mcePrint', function () {
-        if (global$1.browser.isIE()) {
+        if (global.browser.isIE()) {
           editor.getDoc().execCommand('print', false, null);
         } else {
           editor.getWin().print();
@@ -23,27 +23,26 @@
       });
     };
 
-    var register$1 = function (editor) {
+    var register = function (editor) {
+      var onAction = function () {
+        return editor.execCommand('mcePrint');
+      };
       editor.ui.registry.addButton('print', {
         icon: 'print',
         tooltip: 'Print',
-        onAction: function () {
-          return editor.execCommand('mcePrint');
-        }
+        onAction: onAction
       });
       editor.ui.registry.addMenuItem('print', {
         text: 'Print...',
         icon: 'print',
-        onAction: function () {
-          return editor.execCommand('mcePrint');
-        }
+        onAction: onAction
       });
     };
 
     function Plugin () {
-      global.add('print', function (editor) {
-        register(editor);
+      global$1.add('print', function (editor) {
         register$1(editor);
+        register(editor);
         editor.addShortcut('Meta+P', '', 'mcePrint');
       });
     }
