@@ -1,4 +1,4 @@
-import { FieldSchema, ValueSchema } from '@ephox/boulder';
+import { FieldSchema, StructureSchema } from '@ephox/boulder';
 
 import * as Fields from '../../data/Fields';
 import DatasetStore from './DatasetStore';
@@ -6,7 +6,7 @@ import ManualStore from './ManualStore';
 import MemoryStore from './MemoryStore';
 
 export default [
-  FieldSchema.defaultedOf('store', { mode: 'memory' }, ValueSchema.choose('mode', {
+  FieldSchema.defaultedOf('store', { mode: 'memory' }, StructureSchema.choose('mode', {
     memory: MemoryStore,
     manual: ManualStore,
     dataset: DatasetStore
