@@ -1,13 +1,13 @@
-import { FieldProcessorAdt, FieldSchema } from '@ephox/boulder';
+import { FieldProcessor, FieldSchema } from '@ephox/boulder';
 import { Fun } from '@ephox/katamari';
 
 import * as Boxes from '../../alien/Boxes';
 import SnapSchema from './SnapSchema';
 
-const schema: FieldProcessorAdt[] = [
+const schema: FieldProcessor[] = [
   // Is this used?
   FieldSchema.defaulted('useFixed', Fun.never),
-  FieldSchema.strict('blockerClass'),
+  FieldSchema.required('blockerClass'),
   FieldSchema.defaulted('getTarget', Fun.identity),
   FieldSchema.defaulted('onDrag', Fun.noop),
   FieldSchema.defaulted('repositionTarget', true),
