@@ -1,4 +1,4 @@
-import { ValueSchema, FieldSchema } from '@ephox/boulder';
+import { StructureSchema, FieldSchema } from '@ephox/boulder';
 import { Result } from '@ephox/katamari';
 
 import { FormComponentWithLabel, FormComponentWithLabelSpec, formComponentWithLabelFields } from './FormComponent';
@@ -20,12 +20,12 @@ const urlInputFields = formComponentWithLabelFields.concat([
   FieldSchema.defaulted('disabled', false)
 ]);
 
-export const urlInputSchema = ValueSchema.objOf(urlInputFields);
+export const urlInputSchema = StructureSchema.objOf(urlInputFields);
 
-export const urlInputDataProcessor = ValueSchema.objOf([
-  FieldSchema.strictString('value'),
+export const urlInputDataProcessor = StructureSchema.objOf([
+  FieldSchema.requiredString('value'),
   FieldSchema.defaulted('meta', { })
 ]);
 
-export const createUrlInput = (spec: UrlInputSpec): Result<UrlInput, ValueSchema.SchemaError<any>> =>
-  ValueSchema.asRaw<UrlInput>('urlinput', urlInputSchema, spec);
+export const createUrlInput = (spec: UrlInputSpec): Result<UrlInput, StructureSchema.SchemaError<any>> =>
+  StructureSchema.asRaw<UrlInput>('urlinput', urlInputSchema, spec);
