@@ -1,4 +1,4 @@
-import { FieldSchema, ValueSchema } from '@ephox/boulder';
+import { FieldSchema, StructureSchema } from '@ephox/boulder';
 import { Fun, Optional, Result } from '@ephox/katamari';
 
 import { CommonMenuItem, CommonMenuItemSpec, commonMenuItemFields, CommonMenuItemInstanceApi } from './CommonMenuItem';
@@ -24,13 +24,13 @@ export interface ToggleMenuItem extends CommonMenuItem {
   onAction: (api: ToggleMenuItemInstanceApi) => void;
 }
 
-export const toggleMenuItemSchema = ValueSchema.objOf([
-  FieldSchema.strictString('type'),
+export const toggleMenuItemSchema = StructureSchema.objOf([
+  FieldSchema.requiredString('type'),
   FieldSchema.optionString('icon'),
   FieldSchema.defaultedBoolean('active', false),
   FieldSchema.defaultedFunction('onSetup', () => Fun.noop),
-  FieldSchema.strictFunction('onAction')
+  FieldSchema.requiredFunction('onAction')
 ].concat(commonMenuItemFields));
 
-export const createToggleMenuItem = (spec: ToggleMenuItemSpec): Result<ToggleMenuItem, ValueSchema.SchemaError<any>> =>
-  ValueSchema.asRaw('togglemenuitem', toggleMenuItemSchema, spec);
+export const createToggleMenuItem = (spec: ToggleMenuItemSpec): Result<ToggleMenuItem, StructureSchema.SchemaError<any>> =>
+  StructureSchema.asRaw('togglemenuitem', toggleMenuItemSchema, spec);
