@@ -1,10 +1,11 @@
 import { FutureResult } from '@ephox/katamari';
+
 import { DataType } from './DataType';
-import { ResponseBodyDataTypes, ResponseTypeMap } from './HttpData';
+import { ResponseBodyDataTypes, ResponseType, ResponseTypeMap } from './HttpData';
 import { HttpError } from './HttpError';
 import * as JsonResponse from './JsonResponse';
 
-export const validate = <T extends keyof ResponseTypeMap>(responseType: ResponseBodyDataTypes, request: XMLHttpRequest): FutureResult<ResponseTypeMap[T], HttpError> => {
+export const validate = <T extends ResponseType>(responseType: ResponseBodyDataTypes, request: XMLHttpRequest): FutureResult<ResponseTypeMap[T], HttpError<T>> => {
   const normal = () => FutureResult.pure(request.response);
 
   const error = (message: string) => FutureResult.error({
