@@ -6,23 +6,28 @@
  */
 
 import { Fun } from '@ephox/katamari';
+
 import { Bookmark } from '../bookmark/BookmarkTypes';
 import * as FontCommands from '../commands/FontCommands';
 import * as IndentOutdent from '../commands/IndentOutdent';
 import * as LineHeightCommands from '../commands/LineHeight';
 import * as InsertContent from '../content/InsertContent';
 import * as NodeType from '../dom/NodeType';
+import { FormatVars } from '../fmt/FormatTypes';
+import * as EditorFocus from '../focus/EditorFocus';
 import * as InsertBr from '../newline/InsertBr';
 import * as InsertNewLine from '../newline/InsertNewLine';
 import * as SelectionBookmark from '../selection/SelectionBookmark';
 import Editor from './Editor';
 import Env from './Env';
+import { ContentLanguage } from './SettingsTypes';
 import Tools from './util/Tools';
 
 /**
  * This class enables you to add custom editor commands and it contains
  * overrides for native browser commands to address various bugs and issues.
  *
+ * @private
  * @class tinymce.EditorCommands
  */
 
@@ -74,10 +79,12 @@ class EditorCommands {
       return;
     }
 
-    if (!/^(mceAddUndoLevel|mceEndUndoLevel|mceBeginUndoLevel|mceRepaint)$/.test(command) && (!args || !args.skip_focus)) {
-      self.editor.focus();
-    } else {
-      SelectionBookmark.restore(self.editor);
+    if (command.toLowerCase() !== 'mcefocus') {
+      if (!/^(mceAddUndoLevel|mceEndUndoLevel|mceBeginUndoLevel|mceRepaint)$/.test(command) && (!args || !args.skip_focus)) {
+        self.editor.focus();
+      } else {
+        SelectionBookmark.restore(self.editor);
+      }
     }
 
     args = self.editor.fire('BeforeExecCommand', { command, ui, value });
@@ -263,8 +270,8 @@ class EditorCommands {
     return this.editor.formatter.match(name);
   }
 
-  private toggleFormat(name: string, value?) {
-    this.editor.formatter.toggle(name, value ? { value } : undefined);
+  private toggleFormat(name: string, value?: FormatVars) {
+    this.editor.formatter.toggle(name, value);
     this.editor.nodeChanged();
   }
 
@@ -289,6 +296,10 @@ class EditorCommands {
         editor.undoManager.add();
       },
 
+      'mceFocus': (_command, _ui, value?: boolean) => {
+        EditorFocus.focus(editor, value);
+      },
+
       'Cut,Copy,Paste': (command) => {
         const doc = editor.getDoc();
         let failed;
@@ -384,7 +395,7 @@ class EditorCommands {
 
       // Override commands to use the text formatter engine
       'ForeColor,HiliteColor': (command, ui, value) => {
-        self.toggleFormat(command, value);
+        self.toggleFormat(command, { value });
       },
 
       'FontName': (command, ui, value) => {
@@ -399,6 +410,10 @@ class EditorCommands {
         LineHeightCommands.lineHeightAction(editor, value);
       },
 
+      'Lang': (command, ui, lang: ContentLanguage) => {
+        self.toggleFormat(command, { value: lang.code, customValue: lang.customCode });
+      },
+
       'RemoveFormat': (command) => {
         editor.formatter.remove(command);
       },
