@@ -5,7 +5,8 @@
  * For commercial licenses see https://www.tiny.cloud/
  */
 
-import { Type } from '@ephox/katamari';
+import { Obj, Type } from '@ephox/katamari';
+
 import Tools from '../api/util/Tools';
 
 export interface StringPathBookmark {
@@ -30,17 +31,18 @@ export interface IndexBookmark {
 export interface PathBookmark {
   start: number[];
   end?: number[];
+  isFakeCaret?: boolean;
 }
 
 export type Bookmark = StringPathBookmark | RangeBookmark | IdBookmark | IndexBookmark | PathBookmark;
 
 const isStringPathBookmark = (bookmark: Bookmark): bookmark is StringPathBookmark => Type.isString((bookmark as StringPathBookmark).start);
 
-const isRangeBookmark = (bookmark: Bookmark): bookmark is RangeBookmark => bookmark.hasOwnProperty('rng');
+const isRangeBookmark = (bookmark: Bookmark): bookmark is RangeBookmark => Obj.has(bookmark as RangeBookmark, 'rng');
 
-const isIdBookmark = (bookmark: Bookmark): bookmark is IdBookmark => bookmark.hasOwnProperty('id');
+const isIdBookmark = (bookmark: Bookmark): bookmark is IdBookmark => Obj.has(bookmark as IdBookmark, 'id');
 
-const isIndexBookmark = (bookmark: Bookmark): bookmark is IndexBookmark => bookmark.hasOwnProperty('name');
+const isIndexBookmark = (bookmark: Bookmark): bookmark is IndexBookmark => Obj.has(bookmark as IndexBookmark, 'name');
 
 const isPathBookmark = (bookmark: Bookmark): bookmark is PathBookmark => Tools.isArray((bookmark as PathBookmark).start);
 
