@@ -7,9 +7,11 @@
 
 import { Adt, Arr, Fun, Optional, Type } from '@ephox/katamari';
 import { Insert, InsertAll, SugarElement, Traverse } from '@ephox/sugar';
+
 import DOMUtils from '../api/dom/DOMUtils';
 import DomTreeWalker from '../api/dom/TreeWalker';
 import Editor from '../api/Editor';
+import * as Events from '../api/Events';
 import * as Settings from '../api/Settings';
 import Tools from '../api/util/Tools';
 import * as Bookmarks from '../bookmark/Bookmarks';
@@ -21,7 +23,7 @@ import * as SplitRange from '../selection/SplitRange';
 import * as TableCellSelection from '../selection/TableCellSelection';
 import * as CaretFormat from './CaretFormat';
 import * as ExpandRange from './ExpandRange';
-import { FormatAttrOrStyleValue, FormatVars, RemoveFormatPartial } from './FormatTypes';
+import { Format, FormatAttrOrStyleValue, FormatVars } from './FormatTypes';
 import * as FormatUtils from './FormatUtils';
 import * as MatchFormat from './MatchFormat';
 import { mergeSiblings } from './MergeUtils';
@@ -59,10 +61,8 @@ const isTableCellOrRow = (node: Node) => /^(TR|TH|TD)$/.test(node.nodeName);
 const isChildOfInlineParent = (dom: DOMUtils, node: Node, parent: Node): boolean => dom.isChildOf(node, parent) && node !== parent && !dom.isBlock(parent);
 
 const getContainer = (ed: Editor, rng: RangeLikeObject, start?: boolean) => {
-  let container: Node, offset: number;
-
-  container = rng[start ? 'startContainer' : 'endContainer'];
-  offset = rng[start ? 'startOffset' : 'endOffset'];
+  let container = rng[start ? 'startContainer' : 'endContainer'];
+  let offset = rng[start ? 'startOffset' : 'endOffset'];
 
   if (NodeType.isElement(container)) {
     const lastIdx = container.childNodes.length - 1;
@@ -135,28 +135,28 @@ const wrapWithSiblings = (dom: DOMUtils, node: Node, next: boolean, name: string
  * @param {Object} format Format object o match with.
  * @return {boolean} true/false if the format matches.
  */
-const matchName = (dom: DOMUtils, node: Node, format: RemoveFormatPartial) => {
+const matchName = (dom: DOMUtils, node: Node, format: Format) => {
   // Check for inline match
-  if (isEq(node, format.inline)) {
+  if (FormatUtils.isInlineFormat(format) && isEq(node, format.inline)) {
     return true;
   }
 
   // Check for block match
-  if (isEq(node, format.block)) {
+  if (FormatUtils.isBlockFormat(format) && isEq(node, format.block)) {
     return true;
   }
 
   // Check for selector match
-  if (format.selector) {
+  if (FormatUtils.isSelectorFormat(format)) {
     return NodeType.isElement(node) && dom.is(node, format.selector);
   }
 };
 
-const isColorFormatAndAnchor = (node: Node, format: RemoveFormatPartial) => format.links && node.nodeName === 'A';
+const isColorFormatAndAnchor = (node: Node, format: Format) => format.links && node.nodeName === 'A';
 
-const find = (dom: DOMUtils, node: Node, next: boolean, inc?: boolean) => {
-  node = FormatUtils.getNonWhiteSpaceSibling(node, next, inc);
-  return !node || (node.nodeName === 'BR' || dom.isBlock(node));
+const find = (dom: DOMUtils, node: Node, next: boolean, inc?: boolean): boolean => {
+  const sibling = FormatUtils.getNonWhiteSpaceSibling(node, next, inc);
+  return Type.isNullable(sibling) || sibling.nodeName === 'BR' || dom.isBlock(sibling);
 };
 
 /**
@@ -177,12 +177,12 @@ const find = (dom: DOMUtils, node: Node, next: boolean, inc?: boolean) => {
  * @param {Object} format Format rule.
  * @return {Node} Input node.
  */
-const removeNode = (ed: Editor, node: Node, format: RemoveFormatPartial) => {
+const removeNode = (ed: Editor, node: Node, format: Format) => {
   const parentNode = node.parentNode;
-  let rootBlockElm;
+  let rootBlockElm: Node | null;
   const dom = ed.dom, forcedRootBlock = Settings.getForcedRootBlock(ed);
 
-  if (format.block) {
+  if (FormatUtils.isBlockFormat(format)) {
     if (!forcedRootBlock) {
       // Append BR elements if needed before we remove the block
       if (dom.isBlock(node) && !dom.isBlock(parentNode)) {
@@ -207,7 +207,7 @@ const removeNode = (ed: Editor, node: Node, format: RemoveFormatPartial) => {
                 rootBlockElm.appendChild(node);
               }
             } else {
-              rootBlockElm = 0;
+              rootBlockElm = null;
             }
           });
         }
@@ -215,15 +215,15 @@ const removeNode = (ed: Editor, node: Node, format: RemoveFormatPartial) => {
     }
   }
 
-  // Never remove nodes that isn't the specified inline element if a selector is specified too
-  if (format.selector && format.inline && !isEq(format.inline, node)) {
+  // Never remove nodes that aren't the specified inline element if a selector is specified too
+  if (FormatUtils.isMixedFormat(format) && !isEq(format.inline, node)) {
     return;
   }
 
   dom.remove(node, true);
 };
 
-const removeFormatInternal = (ed: Editor, format: RemoveFormatPartial, vars?: FormatVars, node?: Node, compareNode?: Node): RemoveFormatAdt => {
+const removeFormatInternal = (ed: Editor, format: Format, vars?: FormatVars, node?: Node, compareNode?: Node): RemoveFormatAdt => {
   let stylesModified: boolean;
   const dom = ed.dom;
 
@@ -236,7 +236,7 @@ const removeFormatInternal = (ed: Editor, format: RemoveFormatPartial, vars?: Fo
   const elm = node as Element;
 
   // Applies to styling elements like strong, em, i, u, etc. so that if they have styling attributes, the attributes can be kept but the styling element is removed
-  if (format.inline && format.remove === 'all' && Type.isArray(format.preserve_attributes)) {
+  if (FormatUtils.isInlineFormat(format) && format.remove === 'all' && Type.isArray(format.preserve_attributes)) {
     // Remove all attributes except for the attributes specified in preserve_attributes
     const attrsToPreserve = Arr.filter(dom.getAttribs(elm), (attr) => Arr.contains(format.preserve_attributes, attr.name.toLowerCase()));
     dom.removeAllAttribs(elm);
@@ -366,7 +366,7 @@ const removeFormatInternal = (ed: Editor, format: RemoveFormatPartial, vars?: Fo
  * @param {Node} compareNode Optional compare node, if specified the styles will be compared to that node.
  * @return {Boolean} True/false if the node was removed or not.
  */
-const removeFormat = (ed: Editor, format: RemoveFormatPartial, vars?: FormatVars, node?: Node, compareNode?: Node): boolean =>
+const removeFormat = (ed: Editor, format: Format, vars?: FormatVars, node?: Node, compareNode?: Node): boolean =>
   removeFormatInternal(ed, format, vars, node, compareNode).fold(
     Fun.never,
     (newName) => {
@@ -395,7 +395,7 @@ const findFormatRoot = (editor: Editor, container: Node, name: string, vars: For
   return formatRoot;
 };
 
-const removeFormatFromClone = (editor: Editor, format: RemoveFormatPartial, vars: FormatVars, clone: Node) =>
+const removeFormatFromClone = (editor: Editor, format: Format, vars: FormatVars, clone: Node) =>
   removeFormatInternal(editor, format, vars, clone, clone).fold(
     Fun.constant(clone),
     (newName) => {
@@ -408,7 +408,7 @@ const removeFormatFromClone = (editor: Editor, format: RemoveFormatPartial, vars
     Fun.constant(null)
   );
 
-const wrapAndSplit = (editor: Editor, formatList: RemoveFormatPartial[], formatRoot: Node, container: Node, target: Node, split: boolean, format: RemoveFormatPartial, vars: FormatVars) => {
+const wrapAndSplit = (editor: Editor, formatList: Format[], formatRoot: Node, container: Node, target: Node, split: boolean, format: Format, vars: FormatVars) => {
   let clone: Node | null, lastClone: Node, firstClone: Node;
   const dom = editor.dom;
 
@@ -452,7 +452,7 @@ const wrapAndSplit = (editor: Editor, formatList: RemoveFormatPartial[], formatR
 
       // After splitting the nodes may match with other siblings so we need to attempt to merge them
       // Note: We can't use MergeFormats, as that'd create a circular dependency
-      if (format.inline) {
+      if (FormatUtils.isInlineFormat(format)) {
         mergeSiblings(dom, format, vars, lastClone);
       }
     }
@@ -462,7 +462,7 @@ const wrapAndSplit = (editor: Editor, formatList: RemoveFormatPartial[], formatR
 };
 
 const remove = (ed: Editor, name: string, vars?: FormatVars, node?: Node | Range, similar?: boolean) => {
-  const formatList = ed.formatter.get(name) as RemoveFormatPartial[];
+  const formatList = ed.formatter.get(name);
   const format = formatList[0];
   let contentEditable = true;
   const dom = ed.dom;
@@ -475,17 +475,16 @@ const remove = (ed: Editor, name: string, vars?: FormatVars, node?: Node | Range
 
   // Make sure to only check for bookmarks created here (eg _start or _end)
   // as there maybe nested bookmarks
-  const isRemoveBookmarkNode = (node: Node) => Bookmarks.isBookmarkNode(node) && NodeType.isElement(node) && (node.id === '_start' || node.id === '_end');
+  const isRemoveBookmarkNode = (node: Node) =>
+    Bookmarks.isBookmarkNode(node) && NodeType.isElement(node) && (node.id === '_start' || node.id === '_end');
+
+  const removeNodeFormat = (node: Node) =>
+    Arr.exists(formatList, (fmt) => removeFormat(ed, fmt, vars, node, node));
 
   // Merges the styles for each node
   const process = (node: Node) => {
-    let lastContentEditable: boolean, hasContentEditableState: boolean;
-
-    // TINY-6567 Include the last node in the selection
-    const parentNode = node.parentNode;
-    if (NodeType.isText(node) && FormatUtils.hasBlockChildren(dom, parentNode)) {
-      removeFormat(ed, format, vars, parentNode, parentNode);
-    }
+    let lastContentEditable = true;
+    let hasContentEditableState = false;
 
     // Node has a contentEditable value
     if (NodeType.isElement(node) && dom.getContentEditable(node)) {
@@ -499,10 +498,13 @@ const remove = (ed: Editor, name: string, vars?: FormatVars, node?: Node | Range
 
     // Process current node
     if (contentEditable && !hasContentEditableState) {
-      for (let i = 0; i < formatList.length; i++) {
-        if (removeFormat(ed, formatList[i], vars, node, node)) {
-          break;
-        }
+      const removed = removeNodeFormat(node);
+
+      // TINY-6567/TINY-7393: Include the parent if using an expanded selector format and no match was found for the current node
+      const currentNodeMatches = removed || Arr.exists(formatList, (f) => MatchFormat.matchName(dom, node, f));
+      const parentNode = node.parentNode;
+      if (!currentNodeMatches && Type.isNonNullable(parentNode) && FormatUtils.shouldExpandToSelector(format)) {
+        removeNodeFormat(parentNode);
       }
     }
 
@@ -518,6 +520,24 @@ const remove = (ed: Editor, name: string, vars?: FormatVars, node?: Node | Range
         }
       }
     }
+
+    // Note: Assists with cleaning up any stray text decorations that may been applied when text decorations
+    // and text colors were merged together from an applied format
+    // Remove child span if it only contains text-decoration and a parent node also has the same text decoration.
+    const textDecorations = [ 'underline', 'line-through', 'overline' ];
+    Arr.each(textDecorations, (decoration) => {
+      if (NodeType.isElement(node) && ed.dom.getStyle(node, 'text-decoration') === decoration &&
+        node.parentNode && FormatUtils.getTextDecoration(dom, node.parentNode) === decoration) {
+        removeFormat(ed, {
+          deep: false,
+          exact: true,
+          inline: 'span',
+          styles: {
+            textDecoration: decoration
+          }
+        }, null, node);
+      }
+    });
   };
 
   const unwrap = (start?: boolean) => {
@@ -610,27 +630,7 @@ const remove = (ed: Editor, name: string, vars?: FormatVars, node?: Node | Range
 
     // Remove items between start/end
     RangeWalk.walk(dom, expandedRng, (nodes) => {
-      Arr.each(nodes, (node) => {
-        process(node);
-
-        // Note: Assists with cleaning up any stray text decorations that may been applied when text decorations
-        // and text colors were merged together from a applied format
-        // Remove child span if it only contains text-decoration and a parent node also has the same text decoration.
-        const textDecorations = [ 'underline', 'line-through', 'overline' ];
-        Arr.each(textDecorations, (decoration) => {
-          if (NodeType.isElement(node) && ed.dom.getStyle(node, 'text-decoration') === decoration &&
-            node.parentNode && FormatUtils.getTextDecoration(dom, node.parentNode) === decoration) {
-            removeFormat(ed, {
-              deep: false,
-              exact: true,
-              inline: 'span',
-              styles: {
-                textDecoration: decoration
-              }
-            }, null, node);
-          }
-        });
-      });
+      Arr.each(nodes, process);
     });
   };
 
@@ -645,6 +645,7 @@ const remove = (ed: Editor, name: string, vars?: FormatVars, node?: Node | Range
       removeRngStyle(node);
     }
 
+    Events.fireFormatRemove(ed, name, node, vars);
     return;
   }
 
@@ -658,10 +659,11 @@ const remove = (ed: Editor, name: string, vars?: FormatVars, node?: Node | Range
       }
     }
 
+    Events.fireFormatRemove(ed, name, node, vars);
     return;
   }
 
-  if (!selection.isCollapsed() || !format.inline || TableCellSelection.getCellsFromEditor(ed).length) {
+  if (!selection.isCollapsed() || !FormatUtils.isInlineFormat(format) || TableCellSelection.getCellsFromEditor(ed).length) {
     // Remove formatting on the selection
     SelectionUtils.preserve(selection, true, () => {
       SelectionUtils.runOnRanges(ed, removeRngStyle);
@@ -669,7 +671,7 @@ const remove = (ed: Editor, name: string, vars?: FormatVars, node?: Node | Range
 
     // Check if start element still has formatting then we are at: "<b>text|</b>text"
     // and need to move the start into the next text node
-    if (format.inline && MatchFormat.match(ed, name, vars, selection.getStart())) {
+    if (FormatUtils.isInlineFormat(format) && MatchFormat.match(ed, name, vars, selection.getStart())) {
       FormatUtils.moveStart(dom, selection, selection.getRng());
     }
 
@@ -677,6 +679,7 @@ const remove = (ed: Editor, name: string, vars?: FormatVars, node?: Node | Range
   } else {
     CaretFormat.removeCaretFormat(ed, name, vars, similar);
   }
+  Events.fireFormatRemove(ed, name, node, vars);
 };
 
 export {
