@@ -5,8 +5,10 @@
  * For commercial licenses see https://www.tiny.cloud/
  */
 
-import { Cell } from '@ephox/katamari';
+import { Cell, Obj } from '@ephox/katamari';
+
 import PluginManager from 'tinymce/core/api/PluginManager';
+
 import * as Commands from './api/Commands';
 import * as Resize from './core/Resize';
 
@@ -17,10 +19,10 @@ import * as Resize from './core/Resize';
  * @private
  */
 
-export default () => {
+export default (): void => {
   PluginManager.add('autoresize', (editor) => {
     // If autoresize is enabled, disable resize if the user hasn't explicitly enabled it
-    if (!editor.settings.hasOwnProperty('resize')) {
+    if (!Obj.has(editor.settings, 'resize')) {
       editor.settings.resize = false;
     }
     if (!editor.inline) {
