@@ -6,8 +6,10 @@
  */
 
 import Editor from 'tinymce/core/api/Editor';
+import { EditorEvent } from 'tinymce/core/api/util/EventDispatcher';
 
-const fireResizeEditor = (editor: Editor) => editor.fire('ResizeEditor');
+const fireResizeEditor = (editor: Editor): EditorEvent<{}> =>
+  editor.fire('ResizeEditor');
 
 export {
   fireResizeEditor
