@@ -6,10 +6,16 @@
  */
 
 import Editor from 'tinymce/core/api/Editor';
+
 import * as Actions from '../core/Actions';
 import * as CharMap from '../core/CharMap';
 
-const get = (editor: Editor) => {
+export interface Api {
+  readonly getCharMap: () => CharMap.CharMap[];
+  readonly insertChar: (chr: string) => void;
+}
+
+const get = (editor: Editor): Api => {
   const getCharMap = () => {
     return CharMap.getCharMap(editor);
   };
