@@ -5,9 +5,13 @@
  * For commercial licenses see https://www.tiny.cloud/
  */
 
+import { Cell } from '@ephox/katamari';
+
+import Editor from 'tinymce/core/api/Editor';
+
 import * as Dialog from '../ui/Dialog';
 
-const register = (editor, headState) => {
+const register = (editor: Editor, headState: Cell<string>): void => {
   editor.addCommand('mceFullPageProperties', () => {
     Dialog.open(editor, headState);
   });
