@@ -9,12 +9,12 @@ import Editor from 'tinymce/core/api/Editor';
 import AstNode from 'tinymce/core/api/html/Node';
 import Tools from 'tinymce/core/api/util/Tools';
 
-const hasImageClass = (node: AstNode) => {
+const hasImageClass = (node: AstNode): boolean => {
   const className = node.attr('class');
   return className && /\bimage\b/.test(className);
 };
 
-const toggleContentEditableState = (state: boolean) => (nodes: AstNode[]) => {
+const toggleContentEditableState = (state: boolean) => (nodes: AstNode[]): void => {
   let i = nodes.length;
 
   const toggleContentEditable = (node: AstNode) => {
@@ -31,7 +31,7 @@ const toggleContentEditableState = (state: boolean) => (nodes: AstNode[]) => {
   }
 };
 
-const setup = (editor: Editor) => {
+const setup = (editor: Editor): void => {
   editor.on('PreInit', () => {
     editor.parser.addNodeFilter('figure', toggleContentEditableState(true));
     editor.serializer.addNodeFilter('figure', toggleContentEditableState(false));
