@@ -6,13 +6,15 @@
  */
 
 import { Cell } from '@ephox/katamari';
+
 import PluginManager from 'tinymce/core/api/PluginManager';
+
 import * as Commands from './api/Commands';
 import * as UploadSelectedImage from './core/UploadSelectedImage';
 import * as Buttons from './ui/Buttons';
 import * as ContextToolbar from './ui/ContextToolbar';
 
-export default () => {
+export default (): void => {
   PluginManager.add('imagetools', (editor) => {
     const imageUploadTimerState = Cell(0);
     const lastSelectedImageState = Cell(null);
