@@ -6,13 +6,14 @@
  */
 
 import PluginManager from 'tinymce/core/api/PluginManager';
+
 import * as Api from './api/Api';
 import * as Commands from './api/Commands';
 import * as Keyboard from './core/Keyboard';
 import * as Buttons from './ui/Buttons';
 import * as MenuItems from './ui/MenuItems';
 
-export default () => {
+export default (): void => {
   PluginManager.add('lists', (editor) => {
     if (editor.hasPlugin('rtc', true) === false) {
       Keyboard.setup(editor);
