@@ -7,7 +7,8 @@
 
 import Editor from 'tinymce/core/api/Editor';
 
-const shouldIndentOnTab = (editor: Editor) => editor.getParam('lists_indent_on_tab', true);
+const shouldIndentOnTab = (editor: Editor): boolean =>
+  editor.getParam('lists_indent_on_tab', true);
 
 const getForcedRootBlock = (editor: Editor): string => {
   const block = editor.getParam('forced_root_block', 'p');
@@ -20,7 +21,8 @@ const getForcedRootBlock = (editor: Editor): string => {
   }
 };
 
-const getForcedRootBlockAttrs = (editor: Editor): Record<string, string> => editor.getParam('forced_root_block_attrs', {});
+const getForcedRootBlockAttrs = (editor: Editor): Record<string, string> =>
+  editor.getParam('forced_root_block_attrs', {});
 
 export {
   shouldIndentOnTab,
