@@ -6,26 +6,31 @@
  */
 
 import { Arr } from '@ephox/katamari';
-import { Compare, Replication, SugarElement, Traverse } from '@ephox/sugar';
+import { Replication, SugarElement, SugarNode, Traverse } from '@ephox/sugar';
+
 import Editor from 'tinymce/core/api/Editor';
+
 import { Indentation } from '../listmodel/Indentation';
 import * as SplitList from './SplitList';
 
-const outdentDlItem = (editor: Editor, item: SugarElement): void => {
-  if (Compare.is(item, 'dd')) {
+const isDescriptionDetail = SugarNode.isTag('dd');
+const isDescriptionTerm = SugarNode.isTag('dt');
+
+const outdentDlItem = (editor: Editor, item: SugarElement<Node>): void => {
+  if (isDescriptionDetail(item)) {
     Replication.mutate(item, 'dt');
-  } else if (Compare.is(item, 'dt')) {
+  } else if (isDescriptionTerm(item)) {
     Traverse.parent(item).each((dl) => SplitList.splitList(editor, dl.dom, item.dom));
   }
 };
 
-const indentDlItem = (item: SugarElement): void => {
-  if (Compare.is(item, 'dt')) {
+const indentDlItem = (item: SugarElement<Node>): void => {
+  if (isDescriptionTerm(item)) {
     Replication.mutate(item, 'dd');
   }
 };
 
-const dlIndentation = (editor: Editor, indentation: Indentation, dlItems: SugarElement[]) => {
+const dlIndentation = (editor: Editor, indentation: Indentation, dlItems: SugarElement<Node>[]): void => {
   if (indentation === Indentation.Indent) {
     Arr.each(dlItems, indentDlItem);
   } else {
