@@ -5,12 +5,14 @@
  * For commercial licenses see https://www.tiny.cloud/
  */
 
+import Editor from 'tinymce/core/api/Editor';
 import VK from 'tinymce/core/api/util/VK';
+
 import { indentListSelection, outdentListSelection } from '../actions/Indendation';
 import * as Settings from '../api/Settings';
 import * as Delete from './Delete';
 
-const setupTabKey = (editor) => {
+const setupTabKey = (editor: Editor): void => {
   editor.on('keydown', (e) => {
     // Check for tab but not ctrl/cmd+tab since it switches browser tabs
     if (e.keyCode !== VK.TAB || VK.metaKeyPressed(e)) {
@@ -25,7 +27,7 @@ const setupTabKey = (editor) => {
   });
 };
 
-const setup = (editor) => {
+const setup = (editor: Editor): void => {
   if (Settings.shouldIndentOnTab(editor)) {
     setupTabKey(editor);
   }
