@@ -5,11 +5,13 @@
  * For commercial licenses see https://www.tiny.cloud/
  */
 
+import Editor from 'tinymce/core/api/Editor';
 import VK from 'tinymce/core/api/util/VK';
+
 import * as Settings from '../api/Settings';
 import * as Actions from './Actions';
 
-const setup = (editor) => {
+const setup = (editor: Editor): void => {
   const spaces = Settings.getKeyboardSpaces(editor);
 
   if (spaces > 0) {
