@@ -6,28 +6,33 @@
  */
 
 import Editor from 'tinymce/core/api/Editor';
+import { Menu, Toolbar } from 'tinymce/core/api/ui/Ui';
+import { EditorEvent } from 'tinymce/core/api/util/EventDispatcher';
+
 import { Clipboard } from '../api/Clipboard';
 
-const makeSetupHandler = (editor: Editor, clipboard: Clipboard) => (api) => {
+const makeSetupHandler = (editor: Editor, clipboard: Clipboard) => (api: Toolbar.ToolbarToggleButtonInstanceApi | Menu.ToggleMenuItemInstanceApi) => {
   api.setActive(clipboard.pasteFormat.get() === 'text');
-  const pastePlainTextToggleHandler = (e) => api.setActive(e.state);
+  const pastePlainTextToggleHandler = (e: EditorEvent<{ state: boolean }>) => api.setActive(e.state);
   editor.on('PastePlainTextToggle', pastePlainTextToggleHandler);
   return () => editor.off('PastePlainTextToggle', pastePlainTextToggleHandler);
 };
 
-const register = (editor: Editor, clipboard: Clipboard) => {
+const register = (editor: Editor, clipboard: Clipboard): void => {
+  const onAction = () => editor.execCommand('mceTogglePlainTextPaste');
+
   editor.ui.registry.addToggleButton('pastetext', {
     active: false,
     icon: 'paste-text',
     tooltip: 'Paste as text',
-    onAction: () => editor.execCommand('mceTogglePlainTextPaste'),
+    onAction,
     onSetup: makeSetupHandler(editor, clipboard)
   });
 
   editor.ui.registry.addToggleMenuItem('pastetext', {
     text: 'Paste as text',
     icon: 'paste-text',
-    onAction: () => editor.execCommand('mceTogglePlainTextPaste'),
+    onAction,
     onSetup: makeSetupHandler(editor, clipboard)
   });
 };
