@@ -6,10 +6,11 @@
  */
 
 import PluginManager from 'tinymce/core/api/PluginManager';
+
 import * as Commands from './api/Commands';
 import * as Buttons from './ui/Buttons';
 
-export default () => {
+export default (): void => {
   PluginManager.add('save', (editor) => {
     Buttons.register(editor);
     Commands.register(editor);
