@@ -7,11 +7,12 @@
 
 import { ResizeWire } from '@ephox/snooker';
 import { Css, Insert, Remove, SugarBody, SugarElement } from '@ephox/sugar';
+
 import Editor from 'tinymce/core/api/Editor';
 
 import * as Util from '../core/Util';
 
-const createContainer = () => {
+const createContainer = (): SugarElement<HTMLDivElement> => {
   const container = SugarElement.fromTag('div');
 
   Css.setAll(container, {
@@ -28,11 +29,11 @@ const createContainer = () => {
   return container;
 };
 
-const get = (editor: Editor, isResizable: (elm: SugarElement<Element>) => boolean) => {
+const get = (editor: Editor, isResizable: (elm: SugarElement<Element>) => boolean): ResizeWire => {
   return editor.inline ? ResizeWire.body(Util.getBody(editor), createContainer(), isResizable) : ResizeWire.only(SugarElement.fromDom(editor.getDoc()), isResizable);
 };
 
-const remove = (editor: Editor, wire: ResizeWire) => {
+const remove = (editor: Editor, wire: ResizeWire): void => {
   if (editor.inline) {
     Remove.remove(wire.parent());
   }
