@@ -7,7 +7,7 @@
 
 import Editor from 'tinymce/core/api/Editor';
 
-const fireVisualBlocks = (editor: Editor, state: boolean) => {
+const fireVisualBlocks = (editor: Editor, state: boolean): void => {
   editor.fire('VisualBlocks', { state });
 };
 
