@@ -6,7 +6,9 @@
  */
 
 import { Cell } from '@ephox/katamari';
+
 import PluginManager from 'tinymce/core/api/PluginManager';
+
 import * as Api from './api/Api';
 import * as Commands from './api/Commands';
 import * as Settings from './api/Settings';
@@ -14,7 +16,7 @@ import * as Bindings from './core/Bindings';
 import * as Keyboard from './core/Keyboard';
 import * as Buttons from './ui/Buttons';
 
-export default () => {
+export default (): void => {
   PluginManager.add('visualchars', (editor) => {
     const toggleState = Cell(Settings.isEnabledByDefault(editor));
 
