@@ -6,10 +6,12 @@
  */
 
 import { Cell } from '@ephox/katamari';
+
 import Editor from 'tinymce/core/api/Editor';
+
 import * as Actions from './Actions';
 
-const setup = (editor: Editor, toggleState: Cell<boolean>) => {
+const setup = (editor: Editor, toggleState: Cell<boolean>): void => {
   /*
     Note: applyVisualChars does not place a bookmark before modifying the DOM on init.
     This will cause a loss of selection if the following conditions are met:
