@@ -6,9 +6,10 @@
  */
 
 import Editor from 'tinymce/core/api/Editor';
+
 import { WordCountApi } from '../api/Api';
 
-const open = (editor: Editor, api: WordCountApi) => {
+const open = (editor: Editor, api: WordCountApi): void => {
   editor.windowManager.open({
     title: 'Word Count',
     body: {
@@ -50,4 +51,4 @@ const open = (editor: Editor, api: WordCountApi) => {
 
 export {
   open
-};
\ No newline at end of file
+};
