@@ -11,11 +11,10 @@ export const enum ToolbarButtonClasses {
   Icon = 'tox-icon',
   Ticked = 'tox-tbtn--enabled',
   SplitButton = 'tox-split-button',
-  MatchWidth = 'tox-tbtn--select',
-  IconRtl = 'tox-tbtn__icon-rtl'
+  MatchWidth = 'tox-tbtn--select'
 }
 
 export const enum MenuButtonClasses {
   Button = 'tox-mbtn',
   Active = 'tox-mbtn--active'
-}
\ No newline at end of file
+}
